==> v2.0.0.zip: zencart-2.0.0/admin/includes/languages/english/lang.paypal.php <==
<?php
/**
 * @copyright Copyright 2003-2022 Zen Cart Development Team
 * @copyright Portions Copyright 2003 osCommerce
 * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 * @version $Id: Scott C Wilson 2022 Jan 09 New in v1.5.8-alpha $
*/

$define = [
    'TEXT_PAYPAL_IPN_SORT_ORDER_INFO' => 'Display Order: ',
    'TEXT_SORT_PAYPAL_ID_DESC' => 'PayPal Order Received (new - old)',
    'TEXT_SORT_PAYPAL_ID' => 'PayPal Order Received (old - new)',
    'TEXT_SORT_ZEN_ORDER_ID_DESC' => 'Order ID (high - low), PayPal Order Received',
    'TEXT_SORT_ZEN_ORDER_ID' => 'Order ID (low - high), PayPal Order Received',
    'TEXT_PAYMENT_AMOUNT_DESC' => 'Order Amount (high - low)',
    'TEXT_PAYMENT_AMOUNT' => 'Order Amount (low - high)',
    'HEADING_ADMIN_TITLE' => 'PayPal Instant Payment Notifications',
    'HEADING_PAYMENT_STATUS' => 'Payment Status',
    'TEXT_ALL_IPNS' => 'All',
    'TABLE_HEADING_ORDER_NUMBER' => 'Order #',
    'TABLE_HEADING_PAYPAL_ID' => 'PayPal #',
    'TABLE_HEADING_TXN_TYPE' => 'Transaction Type',
    'TABLE_HEADING_PAYMENT_STATUS' => 'Payment Status',
    'TABLE_HEADING_PAYMENT_AMOUNT' => 'Amount',
    'TABLE_HEADING_NUM_HISTORY_ENTRIES' => 'Number of entries in Status History',
    'TABLE_HEADING_ENTRY_NUM' => 'Entry Number',
    'TABLE_HEADING_TRANS_ID' => 'Trans. ID',
    'TABLE_HEADING_PENDING_REASON' => 'Pending Reason',
    'TEXT_INFO_PAYPAL_IPN_HEADING' => 'PayPal IPN',
    'TEXT_DISPLAY_PAYPAL_IPN_NUMBER_OF_TX' => 'Displaying <b>%d</b> to <b>%d</b> (of <b>%d</b> Transactions)',
];

return $define;

==> v2.1.0.zip: zencart-2.1.0/admin/includes/languages/english/lang.paypal.php <==
<?php
/**
 * @copyright Copyright 2003-2024 Zen Cart Development Team
 * @copyright Portions Copyright 2003 osCommerce
 * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 * @version $Id: DrByte 2024 May 27 Modified in v2.1.0-alpha1 $
*/

$define = [
    'TEXT_PAYPAL_IPN_SORT_ORDER_INFO' => 'Display Order: ',
    'TEXT_SORT_PAYPAL_ID_DESC' => 'PayPal Order Received (new - old)',
    'TEXT_SORT_PAYPAL_ID' => 'PayPal Order Received (old - new)',
    'TEXT_SORT_ZEN_ORDER_ID_DESC' => 'Order ID (high - low), PayPal Order Received',
    'TEXT_SORT_ZEN_ORDER_ID' => 'Order ID (low - high), PayPal Order Received',
    'TEXT_PAYMENT_AMOUNT_DESC' => 'Order Amount (high - low)',
    'TEXT_PAYMENT_AMOUNT' => 'Order Amount (low - high)',
    'HEADING_ADMIN_TITLE' => 'PayPal Instant Payment Notifications',
    'HEADING_PAYMENT_STATUS' => 'Payment Status',
    'TEXT_ALL_IPNS' => 'All',
    'TABLE_HEADING_ORDER_NUMBER' => 'Order #',
    'TABLE_HEADING_PAYPAL_ID' => 'PayPal #',
    'TABLE_HEADING_TXN_TYPE' => 'Transaction Type',
    'TABLE_HEADING_PAYMENT_STATUS' => 'Payment Status',
    'TABLE_HEADING_PAYMENT_AMOUNT' => 'Amount',
    'TABLE_HEADING_NUM_HISTORY_ENTRIES' => 'Number of entries in Status History',
    'TABLE_HEADING_ENTRY_NUM' => 'Entry Number',
    'TABLE_HEADING_TRANS_ID' => 'Trans. ID',
    'TABLE_HEADING_PENDING_REASON' => 'Pending Reason',
    'TEXT_INFO_PAYPAL_IPN_HEADING' => 'PayPal IPN',
    'TEXT_DISPLAY_PAYPAL_IPN_NUMBER_OF_TX' => 'Displaying <b>%1$d</b> to <b>%2$d</b> (of <b>%3$d</b> Transactions)',
];

return $define;
